/*
 ***********************************************************************
 *                                                                     *
 * Program to control ICOM radios                                      *
 *                                                                     *
 * Header file                                                         *
 *                                                                     *
 ***********************************************************************
 */

#define TRUE 1			/* veracity */
#define FALSE 0			/* tenacity */
#define BMAX 20			/* packet buffer size */
#define SMAX 80			/* string buffer size */

/*
 * Debug flags (debug)
 */
#define X_TRACE 0x01		/* trace packets */
#define X_ERMSG 0x02		/* bus error messages */

/*
 * Control flags (flags)
 */
#define F_RCV 0x0001		/* 0: transceiver, 1: receiver */
#define F_VFO 0x0002		/* 0: vfo, 1: no vfo (R7000 only) */
#define F_MHZ 0x0004		/* 0: kHz, 1: MHz */
#define F_OFFSET 0x0010		/* 0: no tx offset, 1 tx offset
				 * (VHF/UHF transceivers only) */
#define F_SCAN 0x0008		/* 0: no scan, 1: scan
				 * (275/375/575 only) */

/*
 * Command decode
 */
#define C_ERROR 0		/* unknown command */
#define C_DEBUG 1		/* set debug switch */
#define C_QUIT 2		/* exit program */
#define C_RADIO 3		/* select radio */
#define C_INPUT 4		/* restore channels */
#define C_OUTPUT 5		/* save channels */
#define C_READ 6		/* set/read channel */
#define C_FREQ 7		/* load frequency */
#define C_MODE 8		/* load mode */
#define C_WRITE 9		/* write channel */
#define C_CLEAR 10		/* clear channel */
#define C_SCAN 11		/* specifiy scan frequency range */
#define C_GO 12			/* start scan */
#define C_UP 13			/* step up */
#define C_DOWN 14		/* step down */
#define C_SOFFSET 15		/* write offset */
#define C_DISP 16		/* display freq/mode/offset */

/*
 * Radio control structure
 */
struct icom {
	char name[30];		/* radio name */
	int ident;		/* bus address */
	int maxch;		/* max memory channel */
	int flags;		/* type bits */
	int mchan;		/* memory channel */
	int mode;		/* vfo mode */
	struct modestruct *modetab; /* mode decode table */
	double vfo;		/* vfo frequency (Hz) */
	double offset;		/* tx offset (vhf transceivers only */
	double uband;		/* upper band edge (Hz) */
	double lband;		/* lower band edge (Hz) */
	};

/*
 * Mode decode structure
 */
struct modestruct {
	char name[10];		/* mode name */
	int mode;		/* mode code */
	};
